summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsbinding.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsbinding.h')
-rw-r--r--kjsembed/jsbinding.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/kjsembed/jsbinding.h b/kjsembed/jsbinding.h
index cd79cdc7..1f696be6 100644
--- a/kjsembed/jsbinding.h
+++ b/kjsembed/jsbinding.h
@@ -31,14 +31,14 @@
#include <kjs/types.h>
/**
- * Implement QString-KJS::UString conversion methods. These methods are declared
+ * Implement TQString-KJS::UString conversion methods. These methods are declared
* by KJS, but libkjs doesn't actually contain their implementations.
*
* @version $Id$
*/
namespace KJS {
- inline UString::UString( const TQString &d )
+ inline UString::UString( const TTQString &d )
{
uint len = d.length();
UChar *dat = new UChar[len];
@@ -46,19 +46,19 @@ namespace KJS {
rep = UString::Rep::create(dat, len);
}
- inline TQString UString::qstring() const
+ inline TTQString UString::qstring() const
{
- return TQString((TQChar*) data(), size());
+ return TTQString((TTQChar*) data(), size());
}
- inline TQConstString UString::qconststring() const
+ inline TTQConstString UString::qconststring() const
{
- return TQConstString((TQChar*) data(), size());
+ return TTQConstString((TTQChar*) data(), size());
}
- inline TQString Identifier::qstring() const
+ inline TTQString Identifier::qstring() const
{
- return TQString((TQChar*) data(), size());
+ return TTQString((TTQChar*) data(), size());
}
}
@@ -71,64 +71,64 @@ namespace KJSEmbed {
KJSEMBED_EXPORT JavaScriptArrayType checkArray( KJS::ExecState *exec, const KJS::Value &val );
- /** Converts a TQVariant to the closest possible KJS::Value. */
- KJSEMBED_EXPORT KJS::Value convertToValue( KJS::ExecState *exec, const TQVariant &val);
+ /** Converts a TTQVariant to the closest possible KJS::Value. */
+ KJSEMBED_EXPORT KJS::Value convertToValue( KJS::ExecState *exec, const TTQVariant &val);
- /** Converts a KJS::Value to the closest possible TQVariant. */
- KJSEMBED_EXPORT TQVariant convertToVariant( KJS::ExecState *exec, const KJS::Value &v );
+ /** Converts a KJS::Value to the closest possible TTQVariant. */
+ KJSEMBED_EXPORT TTQVariant convertToVariant( KJS::ExecState *exec, const KJS::Value &v );
/** Returns HTML that documents the specified object. */
- KJSEMBED_EXPORT TQString dumpObject( KJS::ExecState *exec, KJS::Object &obj );
+ KJSEMBED_EXPORT TTQString dumpObject( KJS::ExecState *exec, KJS::Object &obj );
- /** Returns HTML that documents the TQObject facilities of the specified object. */
- KJSEMBED_EXPORT TQString dumpQObject( KJS::ExecState *exec, KJS::Object &obj );
+ /** Returns HTML that documents the TTQObject facilities of the specified object. */
+ KJSEMBED_EXPORT TTQString dumpTQObject( KJS::ExecState *exec, KJS::Object &obj );
- /** Returns a TQStringList that contains all possible properties,
+ /** Returns a TTQStringList that contains all possible properties,
* methods and slots for use with a completion object
*/
- KJSEMBED_EXPORT TQStringList dumpCompletion( KJS::ExecState *exec, KJS::Object &obj);
-
- KJSEMBED_EXPORT TQPen extractQPen(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQBrush extractQBrush(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQPalette extractQPalette(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQPixmap extractQPixmap( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQImage extractQImage( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQString extractQString( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQStringList dumpCompletion( KJS::ExecState *exec, KJS::Object &obj);
+
+ KJSEMBED_EXPORT TTQPen extractTQPen(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQFont extractTQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQBrush extractTQBrush(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQPalette extractTQPalette(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQPixmap extractTQPixmap( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQImage extractTQImage( KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQString extractTQString( KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT int extractInt( KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQColor extractQColor(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQSize extractQSize(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQColor extractTQColor(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQSize extractTQSize(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT bool extractBool(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT double extractDouble(KJS::ExecState *exec, const KJS::List &args, int idx);
KJSEMBED_EXPORT uint extractUInt(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQStringList extractQStringList(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQStringList extractTQStringList(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQDateTime extractQDateTime(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQDate extractQDate(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQTime extractQTime(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQRect extractQRect(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQPoint extractQPoint(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQDateTime extractTQDateTime(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQDate extractTQDate(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQTime extractTQTime(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQRect extractTQRect(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQPoint extractTQPoint(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQFont extractQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQStrList extractQStrList(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQFont extractTQFont(KJS::ExecState *exec, const KJS::List &args, int idx);
+ KJSEMBED_EXPORT TTQStrList extractTQStrList(KJS::ExecState *exec, const KJS::List &args, int idx);
- KJSEMBED_EXPORT TQObject *extractQObject( KJS::ExecState *exec, const KJS::List &args, int idx );
- KJSEMBED_EXPORT TQWidget *extractQWidget( KJS::ExecState *exec, const KJS::List &args, int idx );
+ KJSEMBED_EXPORT TTQObject *extractTQObject( KJS::ExecState *exec, const KJS::List &args, int idx );
+ KJSEMBED_EXPORT TTQWidget *extractTQWidget( KJS::ExecState *exec, const KJS::List &args, int idx );
KJSEMBED_EXPORT JSOpaqueProxy *extractOpaqueProxy( KJS::ExecState *exec, const KJS::List &args, int idx );
// Helpers for Variant conversions....
- KJSEMBED_EXPORT TQStrList convertArrayToStrList( KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT TQStringList convertArrayToStringList( KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT TQDateTime convertDateToDateTime(KJS::ExecState *exec, const KJS::Value &value);
- KJSEMBED_EXPORT TQValueList<TQVariant> convertArrayToList( KJS::ExecState *exec, const KJS::Value &value );
- KJSEMBED_EXPORT TQMap<TQString, TQVariant> convertArrayToMap( KJS::ExecState *exec, const KJS::Value &value );
+ KJSEMBED_EXPORT TTQStrList convertArrayToStrList( KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TTQStringList convertArrayToStringList( KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TTQDateTime convertDateToDateTime(KJS::ExecState *exec, const KJS::Value &value);
+ KJSEMBED_EXPORT TTQValueList<TTQVariant> convertArrayToList( KJS::ExecState *exec, const KJS::Value &value );
+ KJSEMBED_EXPORT TTQMap<TTQString, TTQVariant> convertArrayToMap( KJS::ExecState *exec, const KJS::Value &value );
/**
* This will throw an exception with the error string.
* @returns An error object.
*/
- KJS::Object throwError( KJS::ExecState *exec, const TQString &error, KJS::ErrorType type = KJS::GeneralError );
+ KJS::Object throwError( KJS::ExecState *exec, const TTQString &error, KJS::ErrorType type = KJS::GeneralError );
}
#endif // KJSEMBEDJSBINDING_H